@@ -301,60 +301,34 @@ vt 0.00 0.00 0.00
             f.write("f {}/{}/{} {}/{}/{} {}/{}/{}\n".format(*facestr))
 
 
-def MarchingMesh(
-                array, out_file='model.obj', level=0,
-                spacing=(1., 1., 1.), gradient_direction='descent', step_size=1, 
-                allow_degenerate=True, method='lewiner', mask=None,
-                plot=False, figsize=(4.8,4.8) 
-                ):
-    '''[GLOBAL_METHOD] 
-    Marching cubes on sparse 3-D integer `voxelmap` arrays
+def MarchingMesh(array, out_file='model.obj', level=0, spacing=(1., 1., 1.), gradient_direction='descent', step_size=1, allow_degenerate=True, method='lewiner', mask=None, plot=False, figsize=(4.8,4.8) ):
+    """
+    Marching cubes on sparse 3-D integer `voxelmap` arrays (GLOBAL)
 
     Parameters
-    ----------
+    -------------
     array: np.array((int/float,int/float,int/float))
         3-D array for which to run the marching cubes algorithm   
     out_file : str
         name and/or path for Wavefront .obj file output. This is the common format for OpenGL 3-D model files (default: model.obj) 
-
-    --- FROM SKIMAGE.MEASURE.MARCHING_CUBES ---
     level : float, optional
-        Contour value to search for isosurfaces in `volume`. If not
-        given or None, the average of the min and max of vol is used.
+        Contour value to search for isosurfaces in `volume`. If not given or None, the average of the min and max of vol is used.
     spacing : length-3 tuple of floats, optional
-        Voxel spacing in spatial dimensions corresponding to numpy array
-        indexing dimensions (M, N, P) as in `volume`.
+        Voxel spacing in spatial dimensions corresponding to numpy array indexing dimensions (M, N, P) as in `volume`.
     gradient_direction : string, optional
-        Controls if the mesh was generated from an isosurface with gradient
-        descent toward objects of interest (the default), or the opposite,
-        considering the *left-hand* rule.
-        The two options are:
-        * descent : Object was greater than exterior
-        * ascent : Exterior was greater than object
-
+        Controls if the mesh was generated from an isosurface with gradient descent toward objects of interest (the default), or the opposite, considering the *left-hand* rule.
+        The two options are: -- 'descent' : Object was greater than exterior -- 'ascent' : Exterior was greater than object
     step_size : int, optional
-        Step size in voxels. Default 1. Larger steps yield faster but
-        coarser results. The result will always be topologically correct
-        though.
+        Step size in voxels. Default 1. Larger steps yield faster but coarser results. The result will always be topologically correct though.
     allow_degenerate : bool, optional
-        Whether to allow degenerate (i.e. zero-area) triangles in the
-        end-result. Default True. If False, degenerate triangles are
-        removed, at the cost of making the algorithm slower.
+        Whether to allow degenerate (i.e. zero-area) triangles in the end-result. Default True. If False, degenerate triangles are removed, at the cost of making the algorithm slower.
     method: str, optional
-        One of 'lewiner', 'lorensen' or '_lorensen'. Specify which of
-        Lewiner et al. or Lorensen et al. method will be used. The
-        '_lorensen' flag correspond to an old implementation that will
-        be deprecated in version 0.19.
+        One of 'lewiner', 'lorensen' or '_lorensen'. Specify which of Lewiner et al. or Lorensen et al. method will be used. The '_lorensen' flag correspond to an old implementation that will be deprecated in version 0.19.
     mask : (M, N, P) array, optional
-        Boolean array. The marching cube algorithm will be computed only on
-        True elements. This will save computational time when interfaces
-        are located within certain region of the volume M, N, P-e.g. the top
-        half of the cube-and also allow to compute finite surfaces-i.e. open
-        surfaces that do not end at the border of the cube.
-
+        Boolean array. The marching cube algorithm will be computed only on True elements. This will save computational time when interfaces are located within certain region of the volume M, N, P-e.g. the top half of the cube-and also allow to compute finite surfaces-i.e. open surfaces that do not end at the border of the cube.
     plot: bool
         plots a preliminary 3-D triangulated image if True
-    '''
+    """
 
     '''Adapted from: https://scikit-image.org/docs/stable/auto_examples/edges/plot_marching_cubes.html'''
     # Use marching cubes to obtain the surface mesh of these ellipsoids
@@ -392,8 +366,9 @@ def MarchingMesh(
 
 
 def MeshView(objfile='model.obj',wireframe=False,color='pink',alpha=0.5,background_color='#333333', viewport = [1024, 768]):
-    '''[GLOBAL_METHOD] 
-    MeshView: triangulated mesh view with PyVista 
+    """
+    Triangulated mesh view with PyVista (GLOBAL)
+    
     Parameters
     ----------
     objfile: string
@@ -408,6 +383,6 @@ def MeshView(objfile='model.obj',wireframe=False,color='pink',alpha=0.5,backgrou
         color of background. default: 'pink'
     viewport : (int,int)
         viewport / screen (width, height) for display window (default: 80% your screen's width & height)
-    '''
+    """
     mesh = pv.read(objfile)
     mesh.plot(show_edges=True if wireframe else False, color=color,opacity=alpha,background=background_color,window_size = viewport)
\ No newline at end of file
