@@ -110,7 +110,7 @@ class Model:
             for i in range(len(model_colors)):
                 # self.hashblocks.update({i+1: model_colors[i] })
                 self.hashblocks[i+1] = ['#'+model_colors[i], 1]
-            print('Color list built from file!\nModel().hashblocks =\n',self.hashblocks)
+            print('Color list built from file!\nself.hashblocks =\n',self.hashblocks)
 
         'write array from .txt file voxel color values and locs'
         for i in range(len(elems.T)):
@@ -159,24 +159,26 @@ class Model:
 
         return voxels
 
-    def draw_mpl(self, coloring='nuclear', edgecolors=None, figsize=(6.4, 4.8), axis3don=False):
-        ''' DRAW MATPLOTLIB.VOXELS
-        Draws voxel model after building it with the provided `array`. 
+    def draw_mpl(self, coloring='custom', edgecolors=None, figsize=(6.4, 4.8), axis3don=False):
+        """
+        Draws voxel model after building it with the provided `array` (Matplotlib version. For faster graphics, try the ``draw()`` method (uses PyVista)). 
 
         Parameters
         ----------
         coloring: string  
             voxel coloring scheme
-                'nuclear'  colors model radially, from center to exterior
-                'linear'   colors voxel model vertically, top to bottom. 
-                'voxels'   colors voxel model based on the provided keys to its array integers, defined in the `hashblocks` variable from the `Model` class
+                * 'custom' --> colors voxel model based on the provided keys to its array integers, defined in the `hashblocks` variable from the `Model` class
+                * 'custom: #8599A6' -->  color all voxel types with the #8599A6 hex color (bluish dark gray) and an alpha transparency of 1.0 (default)
+                * 'custom: red, alpha: 0.24' --> color all voxel types red and with an alpha transparency of 0.2
+                * 'nuclear'  colors model radially, from center to exterior
+                * 'linear'   colors voxel model vertically, top to bottom. 
         edgecolors: string/hex
             edge color of voxels (default: None)
         figsize : (float,float)
             defines plot window dimensions. From matplotlib.pyplot.figure(figsize) kwarg. 
         axis3don: bool
             defines presence of 3D axis in voxel model plot (Default: False)
-        '''
+        """
 
         Z, X, Y = np.shape(self.array)
 
@@ -209,6 +211,21 @@ class Model:
 
         def voxel_coloring():
 
+            color_details= coloring.split(':')
+
+            if len(color_details) > 1:
+                if len(color_details) > 2:
+                    color_all = color_details[1].split(',')[0].strip()
+                    alpha_all  = float(color_details[2])
+                else: 
+                    color_all = color_details[1].strip()
+                    alpha_all  = 1.0
+
+                for i in self.hashblocks.keys():
+                    self.hashblocks[i] = [color_all,alpha_all] 
+                    
+            print('Voxelmap draw. Using custom colors:\nself.hashblocks =\n',self.hashblocks)
+
             voxel_colmap = self.hashblocks
             # print(voxel_colmap)
 
@@ -222,8 +239,8 @@ class Model:
                             voxcolors[k][i][j] = vxc_rgba
 
         [gradient_nuclear_coloring() if coloring == 'nuclear'
-         else gradient_linear_coloring() if coloring == 'linear'
-         else voxel_coloring() if coloring == 'voxels' else None]
+        else gradient_linear_coloring() if coloring == 'linear'
+        else voxel_coloring() if coloring[:6] == 'custom' else None]
 
         fig = plt.figure(figsize=figsize)
 
@@ -236,19 +253,22 @@ class Model:
         set_axes_equal(ax)
         plt.show()
 
-    def draw(self, coloring='none', scalars='', background_color='#cccccc', wireframe=False, window_size=[1024, 768],voxel_spacing=(1,1,1)):
-        '''Draws voxel model after building it with the provided `array` with PYVISTA
+    def draw(self, coloring='none', geometry = 'voxels', scalars='', background_color='#cccccc', wireframe=False, window_size=[1024, 768],voxel_spacing=(1,1,1)):
+        '''Draws voxel model after building it with the provided `array` with PyVista library
 
         Parameters
         ----------
         coloring: string  
             voxel coloring scheme
-                'voxels' --> colors voxel model based on the provided keys to its array integers, defined in the `hashblocks` variable from the `Model` class
-                'none'   --> no coloring
-                ELSE:  coloring == cmap (colormap)
-                'cool'      cool colormap
-                'fire'      fire colormap
-                and so on...
+                * 'custom' --> colors voxel model based on the provided keys to its array integers, defined in the `hashblocks` variable from the `Model` class
+                * 'custom: #8599A6' -->  color all voxel types with the #8599A6 hex color (bluish dark gray) and an alpha transparency of 1.0 (default)
+                * 'custom: red, alpha: 0.24' --> color all voxel types red and with an alpha transparency of 0.24
+                * 'none'   --> no coloring 
+                * 'cool'      cool colormap
+                * 'fire'      fire colormap
+                * and so on...
+        geometry: string  
+            voxel geometry. Choose voxels to have a box geometry with geometry='voxels' or spherical one with geometry='particles'
         scalars : list
             list of scalars for cmap coloring scheme
         background_color : string / hex
@@ -268,20 +288,42 @@ class Model:
         if background_color != "":
             pl.background_color = background_color
 
+        if coloring[:6] == 'custom':
+            color_details= coloring.split(':')
+
+            if len(color_details) > 1:
+                if len(color_details) > 2:
+                    color_all = color_details[1].split(',')[0].strip()
+                    alpha_all  = float(color_details[2])
+                else: 
+                    color_all = color_details[1].strip()
+                    alpha_all  = 1.0
+
+                for i in self.hashblocks.keys():
+                    self.hashblocks[i] = [color_all,alpha_all] 
+                    
+            print('Voxelmap draw. Using custom colors:\nself.hashblocks =\n',self.hashblocks)
+
         for i in range(len(centers)):
 
             x_len,y_len,z_len = voxel_spacing
 
-            voxel = pyvista.Cube(center=centers[i],x_length=x_len, y_length=y_len, z_length=z_len)
+            if geometry == 'particles':
+                voxel = pyvista.Sphere(center=centers[i],radius=0.5)
+                smooth = True
+            else:
+                voxel = pyvista.Cube(center=centers[i],x_length=x_len, y_length=y_len, z_length=z_len)
+                smooth= None
+
+            if coloring[:6] == 'custom' :
 
-            if coloring == 'voxels':
                 voxel_color, voxel_alpha = self.hashblocks[voxid[i]]
-                pl.add_mesh(voxel, color=voxel_color, opacity=voxel_alpha,show_edges=True if wireframe else False)
+                pl.add_mesh(voxel, color=voxel_color, smooth_shading=smooth, opacity=voxel_alpha,show_edges=True if wireframe else False)
             elif coloring == 'none':
-                pl.add_mesh(voxel,show_edges=True if wireframe else False)
+                pl.add_mesh(voxel,smooth_shading=smooth, show_edges=True if wireframe else False)
             else:
                 pl.add_mesh(voxel, scalars=[i for i in range(
-                    8)] if scalars == '' else scalars,show_edges=True if wireframe else False, cmap=coloring)
+                    8)] if scalars == '' else scalars,smooth_shading=smooth, show_edges=True if wireframe else False, cmap=coloring)
 
         pl.isometric_view_interactive()
         pl.show(interactive=True)
@@ -349,7 +391,7 @@ class Model:
             Voxel spacing in spatial dimensions corresponding to numpy array indexing dimensions (M, N, P) as in `volume`.
         gradient_direction : string, optional
             Controls if the mesh was generated from an isosurface with gradient descent toward objects of interest (the default), or the opposite, considering the *left-hand* rule.
-            The two options are: -- descent : Object was greater than exterior -- ascent : Exterior was greater than object
+            The two options are: -- 'descent' : Object was greater than exterior -- 'ascent' : Exterior was greater than object
         step_size : int, optional
             Step size in voxels. Default 1. Larger steps yield faster but coarser results. The result will always be topologically correct though.
         allow_degenerate : bool, optional
